@@ -6,27 +6,32 @@ from os import path
 
 class record:
     """
-    Information pour une année.
+    Cette classe permet d'enregistrer une année d'information.
 
-    Cette classe permet d'enregistrer une année d'information. Les instances de 
-    cette classe sont regroupées dans la List account.history.
+    Les instances de cette classe sont regroupées dans la liste *account.history*. Habituellement l'utilisateur utilisera la fonction de méthode *MakeContrib* de la classe *account* (voir ci-dessous) pour créer des entrées.
 
     Parameters
     __________
     year : int
-        année de l'enregistrement
+        année de l'entrée
     earn : float
-        gain admissible
+        gains admissibles
     contrib : float
-        contribution au régime de base
+        cotisation au régime de base
     contrib_s1 : float
-        contribution au régime supplémentaire  pour la hausse du taux de remplacement
-    contrib_s2 : float 
-        contribution au régime supplémentaire  pour la hausse du salaire adminissible (114%MGA)
+        cotisation au régime supplémentaire 1 (en lien avec la hausse du taux de remplacement)
+    contrib_s2 : float
+        cotisation au régime supplémentaire 2 (en lien avec la hausse du salaire admissible à 114% du MGA pré-réforme)
+    contrib_aut : float
+        cotisation au régime de base pour les revenus de travail autonome
+    contrib_aut_s1 : float
+        cotisation au régime supplémentaire 1 (en lien avec la hausse du taux de remplacement) pour les revenus de travail autonome
+    contrib_aut_s2 : float
+        cotisation au régime supplémentaire 2 (en lien avec la hausse du salaire admissible à 114% du MGA pré-réforme) pour les revenus de travail autonome
     kids : boolean
-        enfants de moins de 7  True seulemet pour la personne admissible à l'exemption pour enfants
+        présence d'enfants de moins de 7 ans (True seulement pour la personne admissible à l'exemption pour soins aux enfants en bas âge); défaut=False
     disab : boolean
-        pension d'invalidité
+        rente d'invalidité (non modélisée actuellement) si True, rente de retraite si False; défaut=False
     """
     def __init__(self,year,earn=0.0,contrib=0.0, contrib_s1=0.0, contrib_s2=0.0,
                       contrib_aut=0,contrib_aut_s1=0,contrib_aut_s2=0,kids=False,disab=False):
@@ -43,31 +48,27 @@ class record:
 
 class rules:
     """
-    Règle des régimes RPC et RRQ
+    Classe contenant les règles du RPC et du RRQ.
 
-    Une instance de cette classe charge soit les pamamètres pour le 
-    RRQ (qpp=True) ou pour le RPC (qpp=False). Les paramètres jusqu'en 2025 sont
-    dans params/qpp_history.xlsx et params/cpp_history.xlsx. Passé 2025 les 
-    différentes méthodes retournent soit la valeur de 2025 ou la valeur actualisé, 
-    dépendant du paramètre. En générale pour accéder à un paramètre pour une année 
-    donnée il suffit d'appeler la méthode rules.<param>(year).
+    Une instance de cette classe charge soit les pamamètres pour le RRQ (qpp=True) ou pour le RPC (qpp=False). Les paramètres jusqu'en 2025 sont dans params/qpp_history.xlsx et params/cpp_history.xlsx. Passé 2025 les différentes fonctions de méthodes renvoient soit la valeur de 2025 ou la valeur actualisée, selon le paramètre. En général, pour accéder à un paramètre pour une année donnée il suffit d'appeler la fonction de méthode *rules.<param>(year)*.
+
+    On note que tous les taux de cotisation sont modélisés séparément, car les différentes composantes des cotisations sont traitées de façon différente sur le plan fiscal.
 
     Parameters
     __________
     qpp : boolean
-        Prend la valeur True pour charger les paramètres de RRQ sinon charge RPC
-    
+        True pour charger les paramètres du RRQ, False pour charger ceux du RPC; défaut=True
+
     Attributes
     __________
     cpi : float
-        taux d'indexation
+        taux annuel d'indexation des prestations
     wgr : float
-        taux d'augmentation de YMPE
+        taux annuel d'augmentation du MGA
     lastyear : int
-        lastyear + 1 : année à partir de la quelle rules.cpi et rules.wgr est 
-        utilisé à la place des valeurs du fichier de paramètre.
+        lastyear + 1: année à partir de laquelle *rules.cpi* et *rules.wgr* sont utilisés à la place des valeurs du fichier de paramètres
     self.indexation : float(NxN)
-        tableau pre-calculé d'indexation de 1966 à 2100    
+        tableau pré-calculé d'indexation des prestations de 1966 à 2100
     """
     def __init__(self,qpp=False):
         bnames = ['byear','era','nra','lra']
@@ -85,7 +86,7 @@ class rules:
             self.yrspars = pd.read_excel(params+'/qpp_history.xlsx',names=ynames)
         else :
             #No ca column in cpp
-            for i,name in enumerate(ynames):   
+            for i,name in enumerate(ynames):
                 if name == "ca":
                     ynames.pop(i)
             self.yrspars = pd.read_excel(params+'/cpp_history.xlsx',names=ynames)
@@ -99,17 +100,21 @@ class rules:
         for y in range(2100-1966):
             self.indexation[:,y] =  self.indexation[:,y] + self.cola(1966+y)
         self.indexation = np.cumprod((np.triu(self.indexation)-np.diag(np.diag(self.indexation))+ones_lower), axis=1)
-            
+
     def ympe(self,year):
         """
+        MGA de base pour une année donnée.
+
+        Par défaut, indexé à *wgr* pour les années après 2025.
+
         Parameters
         __________
         year : int
-            Année du paramètre
+            année du paramètre
         Return
         ______
         float
-            MGA pour une année donné. Indexé à wgr pour les années > 2025
+            Montant du MGA de base.
         """
         if (year>self.lastyear):
             value = self.yrspars.loc[self.lastyear,'ympe']
@@ -119,25 +124,34 @@ class rules:
         return value
     def ympe_s2(self,year):
         """
+        Montant du MGA pour le régime supplémentaire pour une année donnée (0 avant 2024, indexé à *wgr* après 2025).
+
         Parameters
         __________
         year : int
-            Année du paramètre
+            année du paramètre
         Return
         ______
         float
-             Montant du MGA pour le régime supplémentaire. 0 avant 2024. 
-             Indexé à wgr après 2025.
+             Montant du MGA pour le régime supplémentaire.
         """
         value = self.ympe(year)
         value *= self.yrspars.loc[min(year,self.stop),'ympe_s2']
         return value
     def exempt(self,year):
         """
+        Montant de l'exemption sur les gains cotisables.
+
+        Après 2025, maintenue fixe à sa valeur nominale de 2025.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
         Return
         ______
         float
-            Montant de l'exemption. Fixe après 2025.
+            Montant de l'exemption.
 
         """
         if (year > self.stop):
@@ -147,10 +161,16 @@ class rules:
         return value
     def worktax(self,year):
         """
+        Taux de cotisation de l'employé au régime de base. Fixe après 2025.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
         Return
         ______
         float
-            Taux de contribution de l'employé au régime de base. Fixe après 2025.
+            Taux de cotisation.
 
         """
 
@@ -161,10 +181,18 @@ class rules:
         return value
     def worktax_s1(self,year):
         """
+        Taux de cotisation de l'employé au régime supplémentaire 1.
+
+        Fixe après 2025.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
         Return
         ______
         float
-            Taux de contribution de l'employé au régime supplémentaire 1. Fixe après 2025.
+            Taux de cotisation.
 
         """
         if (year > self.stop):
@@ -174,11 +202,18 @@ class rules:
         return value
     def worktax_s2(self,year):
         """
+        Taux de cotisation de l'employé au régime supplémentaire 1.
+
+        Fixe après 2025.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
         Return
         ______
         float
-            Taux de contribution de l'employé au régime supplémentaire 2. 
-            Fixe après 2025.
+            Taux de cotisation.
 
         """
         if (year > self.stop):
@@ -187,48 +222,176 @@ class rules:
             value = self.yrspars.loc[year,'worker_s2']
         return value
     def empltax(self,year):
+        """
+        Taux de cotisation de l'employeur au régime de base.
+
+        Fixe après 2025.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de cotisation.
+
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'employer']
         else :
            value = self.yrspars.loc[year,'employer']
         return value
     def empltax_s1(self,year):
+        """
+        Taux de cotisation de l'employeur au régime supplémentaire 1.
+
+        Fixe après 2025.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de cotisation.
+
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'employer_s1']
         else :
             value = self.yrspars.loc[year,'employer_s1']
         return value
     def empltax_s2(self,year):
+        """
+        Taux de cotisation de l'employeur au régime supplémentaire 2.
+
+        Fixe après 2025.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de cotisation.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'employer_s2']
         else :
             value = self.yrspars.loc[year,'employer_s2']
         return value
-    def tax(self,year):
-        return self.worktax(year)+self.empltax(year)
-    def tax_s1(self,year):
-        return self.worktax_s1(year)+self.empltax_s1(year)
-    def tax_s2(self,year):
-        return self.worktax_s2(year)+self.empltax_s2(year)
+    # def tax(self,year):
+    #     """
+    #     Taux de cotisation combiné de l'employeur et de l'employé au régime de base.
+    #
+    #     Parameters
+    #     __________
+    #     year : int
+    #         année du paramètre
+    #     Return
+    #     ______
+    #     float
+    #         Taux de cotisation.
+    #     """
+    #     return self.worktax(year)+self.empltax(year)
+    # def tax_s1(self,year):
+    #     """
+    #     Taux de cotisation combiné de l'employeur et de l'employé au régime supplémentaire 1.
+    #
+    #     Parameters
+    #     __________
+    #     year : int
+    #         année du paramètre
+    #     Return
+    #     ______
+    #     float
+    #         Taux de cotisation.
+    #     """
+    #     return self.worktax_s1(year)+self.empltax_s1(year)
+    # def tax_s2(self,year):
+    #     """
+    #     Taux de cotisation combiné de l'employeur et de l'employé au régime supplémentaire 2.
+    #
+    #     Parameters
+    #     __________
+    #     year : int
+    #         année du paramètre
+    #     Return
+    #     ______
+    #     float
+    #         Taux de cotisation.
+    #     """
+    #     return self.worktax_s2(year)+self.empltax_s2(year)
     def selftax(self,year):
+        """
+        Taux de cotisation sur revenun de travail autonome au régime de base.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de cotisation.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'selfemp']
         else :
             value = self.yrspars.loc[year,'selfemp']
         return value
     def selftax_s1(self,year):
+        """
+        Taux de cotisation sur revenun de travail autonome au régime supplémentaire 1.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de cotisation.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'selfemp_s1']
         else :
             value = self.yrspars.loc[year,'selfemp_s1']
         return value
     def selftax_s2(self,year):
+        """
+        Taux de cotisation sur revenun de travail autonome au régime supplémentaire 2.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de cotisation.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'selfemp_s2']
         else :
             value = self.yrspars.loc[year,'selfemp_s2']
         return value
     def ca(self,year):
+        """
+        Dans le RRQ, facteur d'ajustement en fonction du revenu de la réduction pour rente hâtive (débutant avant 65 ans).
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Facteur d'ajustement.
+        """
         if self.qpp:
             if (year > self.stop):
                 value = self.yrspars.loc[self.stop,'ca']
@@ -238,185 +401,427 @@ class rules:
             value = 0.0
         return value
     def arf(self,year):
+        """
+        Taux de réduction des prestations pour un début avant 65 ans.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de réduction.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'arf']
         else :
             value = self.yrspars.loc[year,'arf']
         return value
     def drc(self,year):
+        """
+        Taux de bonification des prestations pour un début après 65 ans.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de bonification.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'drc']
         else :
             value = self.yrspars.loc[year,'drc']
         return value
     def nympe(self,year):
+        """
+        Nombre d'années utilisé pour calculer le MGA moyen.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Nombre d'années.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'nympe']
         else :
             value = self.yrspars.loc[year,'nympe']
         return value
     def reprate(self,year):
+        """
+        Taux de remplacement du régime de base.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de remplacement.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'reprate']
         else :
             value = self.yrspars.loc[year,'reprate']
         return value
     def reprate_s1(self,year):
+        """
+        Taux de remplacement du régime supplémentaire 1.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de remplacement.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'reprate_s1']
         else :
             value = self.yrspars.loc[year,'reprate_s1']
         return value
     def reprate_s2(self,year):
+        """
+        Taux de remplacement du régime supplémentaire 2.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de remplacement.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'reprate_s2']
         else :
             value = self.yrspars.loc[year,'reprate_s2']
         return value
     def droprate(self,year):
+        """
+        Proportion d'années non prises en compte dans le calcul de la rente de retraite.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Proportion d'années.
+        """
         if (year > self.stop):
             value = self.yrspars.loc[self.stop,'droprate']
         else :
             value = self.yrspars.loc[year,'droprate']
         return value
-    def pu1(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
-        return self.yrspars.loc[yr,'pu1']
-    def pu2(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
-        return self.yrspars.loc[yr,'pu2']
-    def pu3(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
-        return self.yrspars.loc[yr,'pu3']
-    def pu4(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
-        return self.yrspars.loc[yr,'pu4']
+    # def pu1(self,year):
+    #     """
+    #     Parameters
+    #     __________
+    #     year : int
+    #         année du paramètre
+    #     Return
+    #     ______
+    #     float
+    #         NE PAS UTILISER
+    #     """
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+    #     return self.yrspars.loc[yr,'pu1']
+    # def pu2(self,year):
+    #     """
+    #     Return
+    #     ______
+    #     float
+    #         NE PAS UTILISER
+    #     """
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+    #     return self.yrspars.loc[yr,'pu2']
+    # def pu3(self,year):
+    #     """
+    #     Return
+    #     ______
+    #     float
+    #         NE PAS UTILISER
+    #     """
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+    #     return self.yrspars.loc[yr,'pu3']
+    # def pu4(self,year):
+    #     """
+    #     Return
+    #     ______
+    #     float
+    #         NE PAS UTILISER
+    #     """
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+    #     return self.yrspars.loc[yr,'pu4']
     def supp(self,year):
+        """
+        Taux de bonification post-retraite pour les bénéficiaires qui continuent de travailler tout en recevant une prestation de retraite (portion régime de base).
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de bonification.
+        """
         if year > self.stop :
             yr = self.stop
         else:
             yr = year
         return self.yrspars.loc[yr,'supp']
     def supp_s1(self,year):
+        """
+        Taux de bonification post-retraite pour les bénéficiaires qui continuent de travailler tout en recevant une prestation de retraite (portion régime supplémentaire 1).
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de bonification.
+        """
         if year > self.stop :
             yr = self.stop
         else:
             yr = year
         return self.yrspars.loc[yr,'supp_s1']
     def supp_s2(self,year):
+        """
+        Taux de bonification post-retraite pour les bénéficiaires qui continuent de travailler tout en recevant une prestation de retraite (portion régime supplémentaire 2).
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux de bonification.
+        """
         if year > self.stop :
             yr = self.stop
         else:
             yr = year
         return self.yrspars.loc[yr,'supp_s2']
-    def survmax60(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
-        return self.yrspars.loc[yr,'survmax60']
-    def survmax65(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
+    # def survmax60(self,year):
 
-        return self.yrspars.loc[yr,'survmax65']
-    def survage1(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
-        return self.yrspars.loc[yr,'survage1']
-    def survage2(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
-        return self.yrspars.loc[yr,'survage2']
-    def survrate1(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
-        return self.yrspars.loc[yr,'survrate1']
-    def survrate2(self,year):
-        if year > self.stop :
-            yr = self.stop
-        else:
-            yr = year
-        return self.yrspars.loc[yr,'survrate2']
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+    #     return self.yrspars.loc[yr,'survmax60']
+    # def survmax65(self,year):
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+
+    #     return self.yrspars.loc[yr,'survmax65']
+    # def survage1(self,year):
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+    #     return self.yrspars.loc[yr,'survage1']
+    # def survage2(self,year):
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+    #     return self.yrspars.loc[yr,'survage2']
+    # def survrate1(self,year):
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+    #     return self.yrspars.loc[yr,'survrate1']
+    # def survrate2(self,year):
+    #     if year > self.stop :
+    #         yr = self.stop
+    #     else:
+    #         yr = year
+    #     return self.yrspars.loc[yr,'survrate2']
     def era(self,year):
+        """
+        Âge minimum pour commencer à recevoir la rente de retraite (early retirement age).
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Âge minimum.
+        """
         if year > self.stop :
             yr = self.stop
         else:
             yr = year
         return self.yrspars.loc[yr,'era']
     def nra(self,year):
+        """
+        Âge normal de la retraite.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Âge normal.
+        """
         if year > self.stop :
             yr = self.stop
         else:
             yr = year
         return self.yrspars.loc[yr,'nra']
     def disab_rate(self,year):
+        """
+        Taux pour prestation d'invalidité.
+
+        N'est pas utilisé actuellement.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux pour prestation d'invalidité.
+        """
         if year > self.stop :
             yr = self.stop
         else:
             yr = year
         return self.yrspars.loc[yr,'disab_rate']
     def disab_base(self,year):
+        """
+        Montant pour prestation d'invalidité.
+
+        N'est pas utilisé actuellement.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Montant de prestation d'invalidité.
+        """
         if year > self.stop :
             yr = self.stop
         else:
             yr = year
         return self.yrspars.loc[yr,'disab_base']
     def cola(self,year):
+        """
+        Taux annuel d'indexation des prestations une fois que celles-ci ont débuté.
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Taux d'indexation.
+        """
         if year > self.stop :
             value  = self.cpi
         else:
             value = self.yrspars.loc[year,'cola']
         return value
     def gIndexation(self,start,stop):
+        """
+        Calcule l'indexation des prestations pour une période définie par (start,stop).
+
+        Parameters
+        __________
+        start : int
+            première année d'indexation
+        stop : int
+            dernière année d'indexation
+
+        Return
+        ______
+        float
+            Indexation.
+        """
         return self.indexation[start-self.start][stop-self.start]
     def max_benefit(self,year):
+        """
+        Calcul de la prestation maximale possible pour une année donnée de début des prestations (moyenne du MGA des 5 années précédentes)
+
+        Utilisé aux fins du calcul de la réduction ajustée en fonction du revenu dans le RRQ (pour les individus débutant hâtivement leur rente de retraite).
+
+        Parameters
+        __________
+        year : int
+            année du paramètre
+        Return
+        ______
+        float
+            Prestation maximale.
+        """
         return np.mean([self.ympe(x) for x in [max(year-x,1966) for x in range(5)]])*self.reprate(year)/12
-    def chgpar(self,name,y0,y1,value):
-        if (name in self.yrspars.columns):
-            for i in range(y0,y1+1):
-                self.yrspars.loc[i,name] = value
-        else :
-            for i in range(y0,y1+1):
-                pass
-                #self.byrpars.loc[i,name] = value
+    # def chgpar(self,name,y0,y1,value):
+    #     """
+    #     Ne pas utiliser
+    #     """
+    #     if (name in self.yrspars.columns):
+    #         for i in range(y0,y1+1):
+    #             self.yrspars.loc[i,name] = value
+    #     else :
+    #         for i in range(y0,y1+1):
+    #             pass
+    #             #self.byrpars.loc[i,name] = value
 
 class account:
     """
-    Classe principal regroupant l'information sur un individu et comprenant les
-    fonctions de calcul.
-    
-    Principal interface avec le simulateur. Chaque individu simulé doit avoir une
-    instance de classe. 
+    Classe principale regroupant l'information sur un individu et comprenant les fonctions de calcul.
+
+    Principale interface avec le simulateur. Chaque individu simulé doit avoir une instance de cette classe.
 
     Parameters
     __________
     byear : int
         année de naissance
     rules : rules
-        une instance de la classe rules.
-    
-    
+        une instance de la classe rules
+
     """
     def __init__(self,byear,rules=None):
         self.byear = byear
@@ -439,6 +844,20 @@ class account:
         self.cqppcontrib = 0.0
 
     def MakeContrib(self,year,earn,earn_aut=0,kids=False):
+        """
+        Ajoute une année de cotisation (une instance de la classe *record* dans la liste des années de cotisation).
+
+        Parameters
+        __________
+        year : int
+            année de cotisation
+        earn : float
+            revenu d'emploi cotisable
+        earn_aut : float
+            revenu de travail autonome cotisable; défaut=0
+        kids : boolean
+            présence d'enfants de moins de 7 ans (True seulement pour la personne admissible à l'exemption pour soins aux enfants en bas âge); défaut=False
+        """
         if year>=self.rules.start:
             if earn>=self.rules.ympe(year):
                 taxable = self.rules.ympe(year)-self.rules.exempt(year)
@@ -455,7 +874,7 @@ class account:
                 taxable_aut = earn_aut
                 if taxable >=self.rules.exempt(year):
                     taxable -= self.rules.exempt(year)
-                elif taxable + taxable_aut >=self.rules.exempt(year):                 
+                elif taxable + taxable_aut >=self.rules.exempt(year):
                     taxable_aut -= (self.rules.exempt(year)-taxable)
                     taxable = 0.0
                 else:
@@ -466,7 +885,7 @@ class account:
             contrib = self.rules.worktax(year) * taxable
             contrib_aut = self.rules.worktax(year) * taxable_aut * 2
             contrib_s1 = self.rules.worktax_s1(year) * taxable
-            contrib_aut_s1 = self.rules.worktax_s1(year) * taxable_aut * 2 
+            contrib_aut_s1 = self.rules.worktax_s1(year) * taxable_aut * 2
 
             taxable_s2 = np.min( [np.max([earn-self.rules.ympe(year),0.0]) , (self.rules.ympe_s2(year)-self.rules.ympe(year))])
             if taxable_s2>0.0:
@@ -484,8 +903,16 @@ class account:
                                         contrib_aut = contrib_aut,contrib_aut_s1 = contrib_aut_s1,contrib_aut_s2=contrib_aut_s2,kids=kids)
             if self.claimage!=None:
                 self.CalcPRB(year,taxable,taxable_s2,earn)
-            
+
     def ClaimCPP(self,year):
+        """
+        Effectue la demande de débuter les prestations et appelle les fonctions *CalcAMPE* et *CalcBenefit* (voir plus bas).
+
+        Parameters
+        __________
+        year : int
+            année de cotisation
+        """
         currage = self.gAge(year)
         if self.claimage!=None:
            print('already claimed at ',self.claimage,' ...')
@@ -502,10 +929,42 @@ class account:
             else :
                 print('not yet eligible...')
     def gAge(self,year):
+        """
+        Retourne l'âge de l'individu dans une année donnée.
+
+        Parameters
+        __________
+        year : int
+            année
+        Return
+        ______
+        int
+            Âge.
+        """
         return year - self.byear
     def gYear(self,age):
+        """
+        Retourne l'année pour un âge donné.
+
+        Parameters
+        __________
+        year : int
+            Âge
+        Return
+        ______
+        int
+            Année.
+        """
         return self.byear + age
     def CalcAMPE(self,year):
+        """
+        Calcule la moyenne des gains ouvrant droit à pension, en proportion du MGA de chaque année, en tenant des années d'exclusion.
+
+        Parameters
+        __________
+        year : int
+            année de début des prestations
+        """
         # parameters
         yr18 = np.max([self.gYear(18),self.rules.start])
         yr70 = np.min([self.gYear(70),year])
@@ -623,6 +1082,14 @@ class account:
         self.ampe_s2 = (1/12)*np.sum(ape_s2)/40
 
     def CalcBenefit(self,year):
+        """
+        Calcule la prestation de retraite (régimes de base, supplémentaire 1 et supplémentaire 2), à partir de *CalcAMPE* et de nombreuses autres fonctions.
+
+        Parameters
+        __________
+        year : int
+            année de début des prestations
+        """
         if self.receiving==True:
             if (self.gAge(year)==self.claimage):
                 nra = self.rules.nra(year)
@@ -641,19 +1108,33 @@ class account:
                 else :
                     self.benefit *= 1.0+drc*(age-nra)
                     self.benefit_s1 *= 1.0+drc*(age-nra)
-                    self.benefit_s2 *= 1.0+drc*(age-nra)              
+                    self.benefit_s2 *= 1.0+drc*(age-nra)
         else:
             self.benefit = 0.0
             self.benefit_s1 = 0.0
             self.benefit_s2 = 0.0
     def CalcPRB(self,year,taxable,taxable_s2,earn):
+        """
+        Calcule la prestation post-retraite lorsqu'une cotisation a été faite après le début des prestations.
+
+        Parameters
+        __________
+        year : int
+            année de la cotisation
+        taxable : float
+            montant cotisable pour le régime de base et le régime supplémentaire 1
+        taxable_s2 : float
+            montant cotisable pour le régime supplémentaire 2
+        earn : float
+            gains admissibles dans l'année précédente
+        """
         if self.rules.qpp:
             if year>=2014:
                 self.prb[self.gAge(year)-60+1] = (self.prb[self.gAge(year)-60]*(1+self.rules.cola(year))
                                                   + taxable*self.rules.supp(year)/12)
                 self.prb_s1[self.gAge(year)-60+1] = (self.prb_s1[self.gAge(year)-60]*(1+self.rules.cola(year))+
                                                     taxable*self.rules.worktax_s1(year)*100*self.rules.supp_s1(year)/12)
-                self.prb_s2[self.gAge(year)-60+1] = (self.prb_s2[self.gAge(year)-60+1] + 
+                self.prb_s2[self.gAge(year)-60+1] = (self.prb_s2[self.gAge(year)-60+1] +
                                                      taxable_s2*self.rules.worktax_s2(year)*100*self.rules.supp_s2(year)/12)
                 if self.gAge(year)<69:
                     for index in range(self.gAge(year)-60+2,11):
@@ -667,11 +1148,11 @@ class account:
                 arf = self.rules.arf(year)
                 drc = self.rules.drc(year)
                 age = self.gAge(year)
-                upe = np.min([earn,self.rules.ympe(year)]) 
+                upe = np.min([earn,self.rules.ympe(year)])
                 if upe<self.rules.exempt(year) : upe = 0
                 #upe_s2 Need to start only in 2024
                 upe_s2 = np.max([np.min([earn-self.rules.ympe(year),self.rules.ympe_s2(year)-self.rules.ympe(year)]),0.0])
-                #PRB base 
+                #PRB base
                 prb = upe/self.rules.ympe(year) * self.rules.ympe(year+1)*self.rules.supp(year)
                 # PRB S1
                 prb_s1 = upe/self.rules.ympe(year) * self.rules.ympe(year+1)*self.rules.worktax_s1(year)*100*self.rules.supp_s1(year)
@@ -693,44 +1174,116 @@ class account:
                         self.prb_s1[index] = self.prb_s1[index-1]*(1+self.rules.cola(year+index))
                         self.prb_s2[index] = self.prb_s2[index-1]*(1+self.rules.cola(year+index))
     def gBenefit(self,year):
+        """
+        Retourne le montant de la prestation du régime de base pour une année donnée.
+
+        Parameters
+        __________
+        year : int
+            année de la prestation
+        Return
+        ______
+        float
+            Prestation.
+        """
         if self.claimage :
             claimyear = self.gYear(self.claimage)
             return self.benefit * self.rules.gIndexation(claimyear,year)
         else :
             return self.benefit
     def gBenefit_s1(self,year):
+        """
+        Retourne le montant de la prestation du régime supplémentaire 1 pour une année donnée.
+
+        Parameters
+        __________
+        year : int
+            année de la prestation
+        Return
+        ______
+        float
+            Prestation.
+        """
         if self.claimage :
             claimyear = self.gYear(self.claimage)
             return self.benefit_s1 * self.rules.gIndexation(claimyear,year)
         else :
             return self.benefit_s1
     def gBenefit_s2(self,year):
+        """
+        Retourne le montant de la prestation du régime supplémentaire 2 pour une année donnée.
+
+        Parameters
+        __________
+        year : int
+            année de la prestation
+        Return
+        ______
+        float
+            Prestation.
+        """
         if self.claimage :
             claimyear = self.gYear(self.claimage)
             return self.benefit_s2 * self.rules.gIndexation(claimyear,year)
         else :
             return self.benefit_s2
     def gPRB(self,year):
-        if self.gAge(year)<60 : 
+        """
+        Retourne le montant de la prestion post-retraite du régime de base pour une année donnée.
+
+        Parameters
+        __________
+        year : int
+            année de la prestation
+        Return
+        ______
+        float
+            Montant de la prestion post-retraite.
+        """
+        if self.gAge(year)<60 :
             return 0.0
         elif  self.gAge(year)<self.gAge(year)<=70:
             return self.prb[self.gAge(year)-60]
         else :
             return self.prb[10]*self.rules.gIndexation(self.gYear(70),year)
     def gPRB_s1(self,year):
-        if self.gAge(year)<60 : 
+        """
+        Retourne le montant de la prestion post-retraite du régime supplémentaire 1 pour une année donnée.
+
+        Parameters
+        __________
+        year : int
+            année de la prestation
+        Return
+        ______
+        float
+            Montant de la prestion post-retraite.
+        """
+        if self.gAge(year)<60 :
             return 0.0
         elif  self.gAge(year)<self.gAge(year)<=70:
             return self.prb_s1[self.gAge(year)-60]
         else :
-            return self.prb_s1[10]*self.rules.gIndexation(self.gYear(70),year)    
+            return self.prb_s1[10]*self.rules.gIndexation(self.gYear(70),year)
     def gPRB_s2(self,year):
-        if self.gAge(year)<60 : 
+        """
+        Retourne le montant de la prestion post-retraite du régime supplémentaire 2 pour une année donnée.
+
+        Parameters
+        __________
+        year : int
+            année de la prestation
+        Return
+        ______
+        float
+            Montant de la prestion post-retraite.
+        """
+        if self.gAge(year)<60 :
             return 0.0
         elif  self.gAge(year)<self.gAge(year)<=70:
             return self.prb_s2[self.gAge(year)-60]
         else :
-            return self.prb_s2[10]*self.rules.gIndexation(self.gYear(70),year) 
+            return self.prb_s2[10]*self.rules.gIndexation(self.gYear(70),year)
 
     def RunCase(self,claimage=65):
         yr18 = np.max([self.gYear(18),self.rules.start])
@@ -761,9 +1314,9 @@ class account:
                 self.ratio_list[i] = temp_list[0]
                 niter += 1
         return
-    
+
     def SetHistory_fam(self, claimage = 65, age_birth=[]):
-        self.age_birth = age_birth       
+        self.age_birth = age_birth
         yr18 = np.max([self.gYear(18),self.rules.start])
         start_age = self.gAge(yr18)
         nyears = claimage - start_age
@@ -782,6 +1335,9 @@ class account:
 
 
     def ResetCase(self):
+        """
+        Réinitialise l'instance de la classe *account*.
+        """
         self.claimage = None
         self.history = [record(yr) for yr in range(self.byear+18,self.byear+70,1)]
         self.ncontrib = 0
